# Copyright (c) 2011-2022 Martin Becker, Blaubeuren.
# This package is free software; you can redistribute it and/or modify it
# under the terms of the Artistic License 2.0 (see LICENSE file).

use strict;
use warnings;
use ExtUtils::MakeMaker;
use File::Spec;

my $DN = 'Math-Polynomial-Multivariate';
my %versions = map {
    my $module = $_;
    my @path   = ('lib', split /::/, "$module.pm");
    my $file   = join '/', @path;
    my $osfile = File::Spec->catfile(@path);
    $module => {
        file    => $file,
        version => MM->parse_version($osfile),
    }
} qw(
    Math::Polynomial::Multivariate
);

WriteMakefile(
    NAME                => 'Math::Polynomial::Multivariate',
    AUTHOR              => 'Martin Becker <becker-cpan-mp (at) cozap.com>',
    VERSION_FROM        => 'lib/Math/Polynomial/Multivariate.pm',
    ABSTRACT_FROM       => 'lib/Math/Polynomial/Multivariate.pm',
    LICENSE             => 'artistic_2',
    MIN_PERL_VERSION    => '5.008',
    SIGN                => 1,
    CONFIGURE_REQUIRES  => {
        'ExtUtils::MakeMaker' => '6.64',
        'File::Spec'          => '0',
    },
    TEST_REQUIRES => {
        'Test::More'          => '0',
    },
    PREREQ_PM => {
        'overload'            => 0,
        'Carp',               => 0,
    },
    META_MERGE => {
        'meta-spec'    => {
            url        => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec',
            version    => 2,
        },
        provides       => \%versions,
        dynamic_config => 0,
        resources      => {
            bugtracker => {
                web => "https://github.com/mhasch/perl-$DN/issues",
            },
            license => [
                'https://www.perlfoundation.org/artistic-license-20.html'
            ],
            repository => {
                url  => "git://github.com/mhasch/perl-$DN.git",
                web  => "https://github.com/mhasch/perl-$DN",
                type => 'git',
            },
        },
        prereqs => {
            runtime => {
                recommends => {
                    'Math::BigRat' => '0.2619',
                },
            },
        },
    },
);
